package cn.timer.api.controller.disk;

import cn.timer.api.bean.disk.DiskCatalogueFiles;
import cn.timer.api.bean.disk.DiskFiles;
import cn.timer.api.bean.disk.DiskFilesLog;
import cn.timer.api.config.annotation.CurrentUser;
import cn.timer.api.config.annotation.UserBean;
import cn.timer.api.config.enuminterface.JxglEnumInterface;
import cn.timer.api.config.sftp.SftpConfiguration;
import cn.timer.api.dto.disk.DiskCatalogueDto;
import cn.timer.api.dto.disk.DiskFilesDto;
import cn.timer.api.dto.disk.FileInfoDto;
import cn.timer.api.service.FtpService;
import cn.timer.api.utils.Result;
import cn.timer.api.utils.ResultUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import javax.transaction.Transactional;
import java.util.List;


/**
 * 云盘-资源上传文件表
 *
 * @author wuqingjun
 * @email 284718418@qq.com
 * @date 2021-12-27 10:05:49
 */
@Api(tags = "云盘")
@Transactional(rollbackOn = Exception.class)
@RestController
@RequestMapping("/disk")
public class DiskFilesController {

    @Autowired
    private FtpService ftpService;

    @Value("${sftp.client.root}")
    private String root;

    @Value("${sftp.client.targetPath}")
    private String targetPath;

    @Value("${sftp.client.reservedName}")
    private boolean reservedName;

    @Value("${sftp.client.serverUrl}")
    private String serverUrl;


    @ApiOperation(value = "上传普通文件", httpMethod = "POST", notes = "接口发布说明")
    @ResponseBody
    @PostMapping("/upload")
    public Result<Object> upload(@CurrentUser UserBean userBean, @RequestParam(required = true) MultipartFile[] file,
                                 @ApiParam("文件文件夹或共享空间ID") @RequestParam(required = true) Integer catalogueId) {
        if (file == null || file.length == 0) {
            return ResultUtil.error("上传失败,请选择上传文件");
        }
        Integer empNum = userBean.getEmpNum();
        Integer orgCode = userBean.getOrgCode();
        DiskFiles diskFiles = new DiskFiles();
        DiskCatalogueFiles diskCatalogueFiles = new DiskCatalogueFiles();
        DiskFilesLog diskFilesLog = new DiskFilesLog();
        List<FileInfoDto> imageUrls;
        try {
            //上传文件到服务器
            imageUrls = ftpService.uploadFile(targetPath, file, reservedName);
            for (FileInfoDto dto : imageUrls) {
                //新增资源上传文件
                diskFiles.setCreateUserId(empNum);
                diskFiles.setFileType(dto.getFileSuffix());
                //"/home/disk/123456.jpg"
                diskFiles.setDiskPath(root + targetPath + "/" + dto.getFileName());
                diskFiles.setUrlPath(dto.getUrlPath());
                diskFiles.setTitle(dto.getResourceFileName());
                diskFiles.setFileSize(dto.getFileSize());
                // 显示大小:10KB,5M,2G 后续优化
                diskFiles.setShowSize(dto.getFileSize() + "B");
                diskFiles.insert();

                //新增中间关系
                diskCatalogueFiles.setCatalogueId(catalogueId);
                diskCatalogueFiles.setFilesId(diskFiles.getId());
                diskCatalogueFiles.insert();

                //新增 文件浏览记录
                diskFilesLog.setFilePath(dto.getUrlPath());
                diskFilesLog.setFilesId(diskFiles.getId());
                diskFilesLog.setFileSize(dto.getFileSize());
                diskFilesLog.setTitle(dto.getResourceFileName());
                diskFilesLog.setType(JxglEnumInterface.DiskFilesLogType.CREATE_LOG.getType());
                diskFilesLog.setUserId(empNum);
                diskFilesLog.setUserName(userBean.getUserInfo().getName());
                diskFilesLog.insert();

            }
            return ResultUtil.data(imageUrls);
        } catch (Exception e) {
            e.printStackTrace();
        }
        return ResultUtil.error("上传文件失败");
    }

}
